@@ -22,7 +22,7 @@
 #  - TMPDIR (set to a usable temporary directory)
 #  - NETDATA_NIGHTLIES_BASEURL (set the base url for downloading the dist tarball)
 
-# Next unused error code: U001D
+# Next unused error code: U001E
 
 set -e
 
@@ -561,7 +561,7 @@ _safe_download() {
   checked=0
 
   if echo "${url}" | grep -Eq "^file:///"; then
-    run cp "${url#file://}" "${dest}" || return 1
+    cp "${url#file://}" "${dest}" || return 1
     return 0
   fi
 
@@ -734,7 +734,7 @@ parse_version() {
   if [ "${r}" = "latest" ]; then
     # If we get ‘latest’ as a version, return the largest possible
     # version value.
-    printf "99999999999999"
+    printf "999999999999999"
     return 0
   elif echo "${r}" | grep -q '^v.*'; then
     # shellcheck disable=SC2001
@@ -755,15 +755,19 @@ parse_version() {
 
   rm -f "${tmpfile}"
 
-  printf "%03d%03d%03d%05d" "${maj}" "${min}" "${patch}" "${b}"
+  printf "%04d%03d%03d%05d" "${maj}" "${min}" "${patch}" "${b}"
 }
 
-get_latest_version() {
-  if [ "${RELEASE_CHANNEL}" = "stable" ]; then
-    get_netdata_latest_tag "${NETDATA_STABLE_BASE_URL}"
-  else
-    get_netdata_latest_tag "${NETDATA_NIGHTLY_BASE_URL}"
+get_latest_tag() {
+  if [ -z "${_latest_tag}" ]; then
+    if [ "${RELEASE_CHANNEL}" = "stable" ]; then
+        _latest_tag="$(get_netdata_latest_tag "${NETDATA_STABLE_BASE_URL}")"
+    else
+        _latest_tag="$(get_netdata_latest_tag "${NETDATA_NIGHTLY_BASE_URL}")"
+    fi
   fi
+
+  echo "${_latest_tag}"
 }
 
 validate_environment_file() {
@@ -774,45 +778,49 @@ validate_environment_file() {
   fi
 }
 
-update_available() {
-  if [ "$NETDATA_FORCE_UPDATE" = "1" ]; then
-     info "Force update requested"
-     return 0
-  fi
-
+get_current_version() {
   basepath="$(dirname "$(dirname "$(dirname "${NETDATA_LIB_DIR}")")")"
   searchpath="${basepath}/bin:${basepath}/sbin:${basepath}/usr/bin:${basepath}/usr/sbin:${PATH}"
   searchpath="${basepath}/netdata/bin:${basepath}/netdata/sbin:${basepath}/netdata/usr/bin:${basepath}/netdata/usr/sbin:${searchpath}"
   ndbinary="$(PATH="${searchpath}" command -v netdata 2>/dev/null)"
 
   if [ -z "${ndbinary}" ]; then
-    current_version=0
+    _current_version=0
   else
-    current_version="$(parse_version "$(${ndbinary} -v | cut -f 2 -d ' ')")"
+    _current_version="$(parse_version "$(${ndbinary} -v | cut -f 2 -d ' ')")"
   fi
 
-  latest_tag="$(get_latest_version)"
-  latest_version="$(parse_version "${latest_tag}")"
-  path_version="$(echo "${latest_tag}" | cut -f 1 -d "-")"
+  echo "${_current_version:-0}"
+}
 
-  # If we can't get the current version for some reason assume `0`
-  current_version="${current_version:-0}"
+get_latest_version() {
+  parse_version "$(get_latest_tag)"
+}
 
-  # If we can't get the latest version for some reason assume `0`
-  latest_version="${latest_version:-0}"
+update_available() {
+  if [ "$NETDATA_FORCE_UPDATE" = "1" ]; then
+     info "Force update requested"
+     return 0
+  fi
+
+  current_version="$(get_current_version)"
+  latest_version="$(get_latest_version)"
 
   info "Current Version: ${current_version}"
   info "Latest Version: ${latest_version}"
 
-  if [ "${latest_version}" -gt 0 ] && [ "${current_version}" -gt 0 ] && [ "${current_version}" -ge "${latest_version}" ]; then
+  if [ -z "${latest_version}" ] || [ -z "${current_version}" ] ; then
+    info "Unable to compare versions for update check, assuming an update is required."
+    return 0
+  elif [ "${latest_version}" -gt 0 ] && [ "${current_version}" -gt 0 ] && [ "${current_version}" -ge "${latest_version}" ]; then
     info "Newest version (current=${current_version} >= latest=${latest_version}) is already installed"
     return 1
   else
     info "Update available"
 
     if [ "${current_version}" -ne 0 ] && [ "${latest_version}" -ne 0 ]; then
-      current_major="$(${ndbinary} -v | cut -f 2 -d ' ' | cut -f 1 -d '.' | tr -d 'v')"
-      latest_major="$(echo "${latest_tag}" | cut -f 1 -d '.' | tr -d 'v')"
+      current_major="$(echo "${current_version}" | head -c 4)"
+      latest_major="$(echo "${latest_version}" | head -c 4)"
 
       if [ "${current_major}" -ne "${latest_major}" ]; then
         update_safe=0
@@ -887,7 +895,7 @@ update_build() {
       tar -xf netdata-latest.tar.gz >&3 2>&3
       rm netdata-latest.tar.gz >&3 2>&3
       if [ -z "$path_version" ]; then
-        latest_tag="$(get_latest_version)"
+        latest_tag="$(get_latest_tag)"
         path_version="$(echo "${latest_tag}" | cut -f 1 -d "-")"
       fi
       cd "$(find . -maxdepth 1 -type d -name "netdata-${path_version}*" | head -n 1)" || fatal "Failed to switch to build directory" U0017
@@ -1003,7 +1011,8 @@ update_static() {
     cd "${PREVDIR}"
   fi
   [ -n "${logfile}" ] && rm "${logfile}" && logfile=
-  exit 0
+
+  return 0
 }
 
 get_new_binpkg_major() {
@@ -1115,6 +1124,8 @@ update_binpkg() {
       ;;
   esac
 
+  initial_version="$(get_current_version)"
+
   if [ -n "${repo_subcmd}" ]; then
     # shellcheck disable=SC2086
     env ${env} ${pm_cmd} ${repo_subcmd} ${repo_update_opts} >&3 2>&3 || fatal "Failed to update repository metadata." U000C
@@ -1165,6 +1176,23 @@ update_binpkg() {
     fi
   fi
 
+  current_version="$(get_current_version)"
+  latest_version="$(get_latest_version)"
+
+  if [ "${current_version}" -ne 0 ] && [ "${latest_version}" -ne 0 ]; then
+    if [ "${current_version}" -lt "${latest_version}" ] && [ "${initial_version}" -eq "${current_version}" ]; then
+      error ""
+      error "NETDATA WAS NOT UPDATED!"
+      error ""
+      error "A newer version of Netdata is available, but the system package manager does not appear to have updated to that version."
+      error ""
+      error "Most likely, your system is not up to date, and you have it configured in a way that prevents updating one or more of Netdata's dependencies."
+      error "Please try updating your system manually and then re-running the Netdata updater before reporting an issue with the update process."
+      error ""
+      fatal "Package manager did not fully update Netdata despite not reporting a failure." U001D
+    fi
+  fi
+
   [ -n "${logfile}" ] && rm "${logfile}" && logfile=
   return 0
 }
