@@ -35,7 +35,7 @@ enum netdata_mount_syscalls {
 };
 
 extern struct config mount_config;
-void *ebpf_mount_thread(void *ptr);
+void ebpf_mount_thread(void *ptr);
 extern netdata_ebpf_targets_t mount_targets[];
 
 #endif /* NETDATA_EBPF_MOUNT_H */
