@@ -411,7 +411,8 @@ int test_dbengine(void) {
     sleep(5);
 
     rrd_wrlock();
-    rrdeng_quiesce((struct rrdengine_instance *)host->db[0].si, false);
+    rrdeng_quiesce((struct rrdengine_instance *)host->db[0].si);
+    rrdeng_flush_all((struct rrdengine_instance *)host->db[0].si);
     rrdeng_exit((struct rrdengine_instance *)host->db[0].si);
     rrdeng_enq_cmd(NULL, RRDENG_OPCODE_SHUTDOWN_EVLOOP, NULL, NULL, STORAGE_PRIORITY_BEST_EFFORT, NULL, NULL);
     rrd_wrunlock();
