@@ -293,7 +293,7 @@ void journalfile_v2_data_unmount_cleanup(time_t now_s) {
         if(!ctx) continue;
 
         struct rrdengine_datafile *datafile;
-        if(uv_rwlock_tryrdlock(&ctx->datafiles.rwlock) != 0)
+        if(netdata_rwlock_tryrdlock(&ctx->datafiles.rwlock) != 0)
             continue;
 
         bool first_then_next = true;
@@ -328,7 +328,7 @@ void journalfile_v2_data_unmount_cleanup(time_t now_s) {
             if (unmount)
                 journalfile_v2_mounted_data_unmount(journalfile, false, false);
         }
-        uv_rwlock_rdunlock(&ctx->datafiles.rwlock);
+        netdata_rwlock_rdunlock(&ctx->datafiles.rwlock);
     }
 }
 
@@ -655,6 +655,7 @@ static void journalfile_restore_extent_metadata(struct rrdengine_instance *ctx,
 
     time_t now_s = max_acceptable_collected_time();
     time_t extent_first_time_s = journalfile->v2.first_time_s ? journalfile->v2.first_time_s : LONG_MAX;
+    time_t extent_last_time_s = journalfile->v2.last_time_s ? journalfile->v2.last_time_s : 0;
     for (i = 0; i < count ; ++i) {
         nd_uuid_t *temp_id;
         uint8_t page_type = jf_metric_data->descr[i].type;
@@ -709,16 +710,23 @@ static void journalfile_restore_extent_metadata(struct rrdengine_instance *ctx,
             mrg_metric_expand_retention(main_mrg, metric, vd.start_time_s, vd.end_time_s, vd.update_every_s);
 
         pgc_open_add_hot_page(
-                (Word_t)ctx, metric_id, vd.start_time_s, vd.end_time_s, vd.update_every_s,
-                journalfile->datafile,
-                jf_metric_data->extent_offset, jf_metric_data->extent_size, jf_metric_data->descr[i].page_length);
+            (Word_t)ctx,
+            metric_id,
+            vd.start_time_s,
+            vd.end_time_s,
+            vd.update_every_s,
+            journalfile->datafile,
+            jf_metric_data->extent_offset,
+            jf_metric_data->extent_size);
 
         extent_first_time_s = MIN(extent_first_time_s, vd.start_time_s);
+        extent_last_time_s = MAX(extent_last_time_s, vd.end_time_s);
 
         mrg_metric_release(main_mrg, metric);
     }
 
     journalfile->v2.first_time_s = extent_first_time_s;
+    journalfile->v2.last_time_s = extent_last_time_s;
 
     time_t old = __atomic_load_n(&ctx->atomic.first_time_s, __ATOMIC_RELAXED);;
     do {
@@ -823,7 +831,7 @@ static uint64_t journalfile_iterate_transactions(struct rrdengine_instance *ctx,
 
             max_size = pos + size_bytes - pos_i;
             ret = journalfile_replay_transaction(ctx, journalfile, buf + pos_i, &id, max_size);
-            if (!ret) /* TODO: support transactions bigger than 4K */
+            if (!ret)
                 /* unknown transaction size, move on to the next block */
                 pos_i = ALIGN_BYTES_FLOOR(pos_i + RRDENG_BLOCK_SIZE);
             else
@@ -1003,6 +1011,8 @@ void journalfile_v2_populate_retention_to_mrg(struct rrdengine_instance *ctx, st
     time_t global_first_time_s;
     bool failed = false;
     uint32_t entries;
+    // Calculate number of samples here and update once the file is loaded
+    uint64_t journal_samples = 0;
     PROTECTED_ACCESS_SETUP(data_start, journalfile->mmap.size, path_v2, "mrg-load");
     if(no_signal_received) {
         entries = j2_header->metric_count;
@@ -1015,7 +1025,14 @@ void journalfile_v2_populate_retention_to_mrg(struct rrdengine_instance *ctx, st
             time_t end_time_s = header_start_time_s + metric->delta_end_s;
 
             mrg_update_metric_retention_and_granularity_by_uuid(
-                main_mrg, (Word_t)ctx, &metric->uuid, start_time_s, end_time_s, metric->update_every_s, now_s);
+                main_mrg,
+                (Word_t)ctx,
+                &metric->uuid,
+                start_time_s,
+                end_time_s,
+                metric->update_every_s,
+                now_s,
+                &journal_samples);
 
             metric++;
         }
@@ -1027,6 +1044,8 @@ void journalfile_v2_populate_retention_to_mrg(struct rrdengine_instance *ctx, st
     if (unlikely(failed))
         return;
 
+    __atomic_add_fetch(&ctx->atomic.samples, journal_samples, __ATOMIC_RELAXED);
+
     usec_t ended_ut = now_monotonic_usec();
 
     nd_log_daemon(NDLP_DEBUG, "DBENGINE: journal v2 of tier %d, datafile %u populated, size: %0.2f MiB, metrics: %0.2f k, %0.2f ms"
@@ -1179,7 +1198,7 @@ void *journalfile_v2_write_extent_list(Pvoid_t JudyL_extents_pos, void *data)
         ext_info = *PValue;
         size_t index = ext_info->index;
         j2_extent_base[index].file_index = 0;
-        j2_extent_base[index].datafile_offset = ext_info->pos;
+        j2_extent_base[index].datafile_offset = BLOCK_TO_OFFSET(ext_info->block);
         j2_extent_base[index].datafile_size = ext_info->bytes;
         j2_extent_base[index].pages = ext_info->number_of_pages;
         count++;
@@ -1246,14 +1265,12 @@ void *journalfile_v2_write_data_page(struct journal_v2_header *j2_header, void *
     if (journalfile_verify_space(j2_header, data, sizeof(*data_page)))
         return NULL;
 
-    struct extent_io_data *ei = page_info->custom_data;
-
     data_page->delta_start_s = (uint32_t) (page_info->start_time_s - (time_t) (j2_header->start_time_ut) / USEC_PER_SEC);
     data_page->delta_end_s = (uint32_t) (page_info->end_time_s - (time_t) (j2_header->start_time_ut) / USEC_PER_SEC);
     data_page->extent_index = page_info->extent_index;
 
     data_page->update_every_s = page_info->update_every_s;
-    data_page->page_length = (uint16_t) (ei ? ei->page_length : page_info->page_length);
+    data_page->page_length = 0;
     data_page->type = 0;
 
     return ++data_page;
@@ -1296,6 +1313,10 @@ bool journalfile_migrate_to_v2_callback(Word_t section, unsigned datafile_fileno
                                         Pvoid_t JudyL_metrics, Pvoid_t JudyL_extents_pos,
                                         size_t number_of_extents, size_t number_of_metrics, size_t number_of_pages, void *user_data)
 {
+    // Nothing to migrate if no metrics
+    if (number_of_metrics == 0)
+        return true;
+
     char path[RRDENG_PATH_MAX];
     Pvoid_t *PValue;
     struct rrdengine_instance *ctx = (struct rrdengine_instance *) section;
@@ -1584,7 +1605,11 @@ int journalfile_load(struct rrdengine_instance *ctx, struct rrdengine_journalfil
     nd_log_daemon(NDLP_DEBUG, "DBENGINE: journal file \"%s\" loaded (size:%" PRIu64 ").", path, file_size);
 
     bool is_last_file = (ctx_last_fileno_get(ctx) == journalfile->datafile->fileno);
-    if (is_last_file && journalfile->datafile->pos <= rrdeng_target_data_file_size(ctx) / 3) {
+    bool has_old_data = false;
+    if (ctx->config.tier == 0 && journalfile->v2.last_time_s > 0)
+        has_old_data = (now_realtime_sec() - journalfile->v2.last_time_s) > 86400;
+
+    if (is_last_file && journalfile->datafile->pos <= rrdeng_target_data_file_size(ctx) / 3 && !has_old_data) {
         ctx->loading.create_new_datafile_pair = false;
         return 0;
     }
