@@ -851,7 +851,7 @@ static ALWAYS_INLINE void *aral_get_free_slot___no_lock_required(ARAL *ar, ARAL_
     aral_page_available_lock(ar, page);
 
     while(!page->available.list) {
-        uint32_t bitmap = __atomic_load_n(&page->incoming_partition_bitmap, __ATOMIC_RELAXED);
+        uint32_t bitmap = __atomic_load_n(&page->incoming_partition_bitmap, __ATOMIC_ACQUIRE);
         if (!bitmap)
             fatal("ARAL: bitmap of incoming free elements cannot be empty at this point");
 
@@ -868,7 +868,7 @@ static ALWAYS_INLINE void *aral_get_free_slot___no_lock_required(ARAL *ar, ARAL_
             if (aral_page_incoming_trylock(ar, page, partition)) {
                 page->available.list = page->incoming[partition].list;
                 page->incoming[partition].list = NULL;
-                __atomic_fetch_and(&page->incoming_partition_bitmap, ~(1U << partition), __ATOMIC_RELAXED);
+                __atomic_fetch_and(&page->incoming_partition_bitmap, ~(1U << partition), __ATOMIC_RELEASE);
                 aral_page_incoming_unlock(ar, page, partition);
                 break;
             }
@@ -903,7 +903,7 @@ static inline void aral_add_free_slot___no_lock_required(ARAL *ar, ARAL_PAGE *pa
             if (aral_page_incoming_trylock(ar, page, partition)) {
                 fr->next = page->incoming[partition].list;
                 page->incoming[partition].list = fr;
-                __atomic_fetch_or(&page->incoming_partition_bitmap, 1U << partition, __ATOMIC_RELAXED);
+                __atomic_fetch_or(&page->incoming_partition_bitmap, 1U << partition, __ATOMIC_RELEASE);
                 aral_page_incoming_unlock(ar, page, partition);
                 return;
             }
@@ -1062,12 +1062,24 @@ void aral_freez_internal(ARAL *ar, void *ptr TRACE_ALLOCATIONS_FUNCTION_DEFINITI
         }
 
         // this is the last page with free items - keep it
-        page->available.list = NULL;
-        page->incoming_partition_bitmap = 0;
-        for(size_t p = 0; p < ARAL_PAGE_INCOMING_PARTITIONS; p++)
-            page->incoming[p].list = NULL;
-
+        // Reset elements_segmented first to prevent new fast-path allocations
         __atomic_store_n(&page->elements_segmented, 0, __ATOMIC_RELEASE);
+
+        // Clear available list under its lock
+        aral_page_available_lock(ar, page);
+        page->available.list = NULL;
+        aral_page_available_unlock(ar, page);
+
+        // Clear incoming partition lists under their respective locks
+        // to synchronize with allocators in aral_get_free_slot___no_lock_required
+        for(size_t p = 0; p < ARAL_PAGE_INCOMING_PARTITIONS; p++) {
+            aral_page_incoming_lock(ar, page, p);
+            page->incoming[p].list = NULL;
+            aral_page_incoming_unlock(ar, page, p);
+        }
+
+        // Clear bitmap last with atomic operation to ensure visibility
+        __atomic_store_n(&page->incoming_partition_bitmap, 0, __ATOMIC_RELEASE);
         __atomic_store_n(&page->refcount, 0, __ATOMIC_RELAXED);
         aral_unlock(ar);
     }
@@ -1406,7 +1418,7 @@ static inline struct aral_unittest_entry *unittest_aral_malloc(ARAL *ar, bool ma
     return t;
 }
 
-static void *aral_test_thread(void *ptr) {
+static void aral_test_thread(void *ptr) {
     struct aral_unittest_config *auc = ptr;
     ARAL *ar = auc->ar;
     size_t elements = auc->elements;
@@ -1504,8 +1516,6 @@ static void *aral_test_thread(void *ptr) {
     } while(!auc->single_threaded && !__atomic_load_n(&auc->stop, __ATOMIC_RELAXED));
 
     freez(pointers);
-
-    return ptr;
 }
 
 int aral_stress_test(size_t threads, size_t elements, size_t seconds) {
